@@ -45,7 +45,6 @@ class DataApi(tornado.web.RequestHandler):
                 'value': 'HTTP请求体错误！' + str(e)
             }
             res = json.dumps(result, ensure_ascii=False)
-            self.set_header('Access-Control-Allow-Origin', '*')  # 允许跨域访问
             self.write(res)
             return 
             
@@ -83,12 +82,15 @@ class DataApi(tornado.web.RequestHandler):
                 }
                 res = json.dumps(result, ensure_ascii=False)
 
-        self.set_header('Access-Control-Allow-Origin', '*')  # 允许跨域访问
+        if self.request.headers.get('Origin'):
+            self.set_header('Access-Control-Allow-Credentials', 'true')
+            self.set_header('Access-Control-Allow-Origin', self.request.headers.get('Origin'))
         self.write(res)
 
     async def options(self, *args, **kwargs):
         self.set_status(204)
-        self.set_header('Access-Control-Allow-Origin', '*')
+        self.set_header('Access-Control-Allow-Credentials', 'true')
+        self.set_header('Access-Control-Allow-Origin', self.request.headers.get('Origin'))
         self.set_header('Access-Control-Allow-Headers', 'content-type')
         self.set_header('Access-Control-Allow-Methods', 'GET, POST, OPTIONS')
 
@@ -202,12 +204,15 @@ class StreamApi(tornado.web.RequestHandler):
                 }
                 res = json.dumps(result, ensure_ascii=False)
 
-        self.set_header('Access-Control-Allow-Origin', '*')  # 允许跨域访问
+        if self.request.headers.get('Origin'):
+            self.set_header('Access-Control-Allow-Credentials', 'true')
+            self.set_header('Access-Control-Allow-Origin', self.request.headers.get('Origin'))
         self.write(res)
 
     async def options(self, *args, **kwargs):
         self.set_status(204)
-        self.set_header('Access-Control-Allow-Origin', '*')
+        self.set_header('Access-Control-Allow-Credentials', 'true')
+        self.set_header('Access-Control-Allow-Origin', self.request.headers.get('Origin'))
         self.set_header('Access-Control-Allow-Headers', 'content-type')
         self.set_header('Access-Control-Allow-Methods', 'GET, POST, OPTIONS')
 
@@ -274,8 +279,10 @@ class FileApi(tornado.web.RequestHandler):
                 'value': 'HTTP文件上传请求体错误！' + str(e)
             }
             res = json.dumps(result, ensure_ascii=False)
-            self.set_header('Access-Control-Allow-Credentials', 'true')
-            self.set_header('Access-Control-Allow-Origin', self.request.headers.get('Origin'))
+
+            if self.request.headers.get('Origin'):
+                self.set_header('Access-Control-Allow-Credentials', 'true')
+                self.set_header('Access-Control-Allow-Origin', self.request.headers.get('Origin'))
             self.write(res)
             return 
 
@@ -316,8 +323,9 @@ class FileApi(tornado.web.RequestHandler):
                 }
                 res = json.dumps(result, ensure_ascii=False)
 
-        self.set_header('Access-Control-Allow-Credentials', 'true')
-        self.set_header('Access-Control-Allow-Origin', self.request.headers.get('Origin'))
+        if self.request.headers.get('Origin'):
+            self.set_header('Access-Control-Allow-Credentials', 'true')
+            self.set_header('Access-Control-Allow-Origin', self.request.headers.get('Origin'))
         self.write(res)
 
     async def options(self, *args, **kwargs):
@@ -357,7 +365,10 @@ class GatewayApi(tornado.web.RequestHandler):
 
             self.set_status(response.status_code)
             self._headers = HTTPHeaders(response.headers)  # 注意：需要强制类型转换
-            self.set_header("Access-Control-Allow-Origin", "*")  # 允许跨域访问
+
+            if self.request.headers.get('Origin'):
+                self.set_header('Access-Control-Allow-Credentials', 'true')
+                self.set_header('Access-Control-Allow-Origin', self.request.headers.get('Origin'))
             self.write(response.content)
         else:
             self.set_status(500)
@@ -394,8 +405,10 @@ class GatewayApi(tornado.web.RequestHandler):
                 json.loads(response.text, encoding='utf-8')
             except:
                 self._headers = HTTPHeaders(response.headers)  # 注意：需要强制类型转换
-            self.set_header('Access-Control-Allow-Credentials', 'true')
-            self.set_header('Access-Control-Allow-Origin', self.request.headers.get('Origin'))
+
+            if self.request.headers.get('Origin'):
+                self.set_header('Access-Control-Allow-Credentials', 'true')
+                self.set_header('Access-Control-Allow-Origin', self.request.headers.get('Origin'))
             self.write(response.content)
         else:
             self.set_status(500)
@@ -458,7 +471,9 @@ class SpecialApi(tornado.web.RequestHandler):
         result = output['result']
 
         if result['status'] == 'ok':
-            self.set_header("Access-Control-Allow-Origin", "*")  # 允许跨域访问
+            if self.request.headers.get('Origin'):
+                self.set_header('Access-Control-Allow-Credentials', 'true')
+                self.set_header('Access-Control-Allow-Origin', self.request.headers.get('Origin'))
             self.write(result['value'])
         else:
             self.set_status(400)
@@ -482,8 +497,9 @@ class SpecialApi(tornado.web.RequestHandler):
         result = output['result']
 
         if result['status'] == 'ok':
-            self.set_header('Access-Control-Allow-Credentials', 'true')
-            self.set_header('Access-Control-Allow-Origin', self.request.headers.get('Origin'))
+            if self.request.headers.get('Origin'):
+                self.set_header('Access-Control-Allow-Credentials', 'true')
+                self.set_header('Access-Control-Allow-Origin', self.request.headers.get('Origin'))
             self.write(result['value'])
         else:
             self.set_status(400)
@@ -544,7 +560,10 @@ class SpecialGatewayApi(tornado.web.RequestHandler):
                 json.loads(response.text, encoding='utf-8')
             except:
                 self._headers = HTTPHeaders(response.headers)  # 注意：需要强制类型转换
-            self.set_header("Access-Control-Allow-Origin", "*")  # 允许跨域访问
+
+            if self.request.headers.get('Origin'):
+                self.set_header('Access-Control-Allow-Credentials', 'true')
+                self.set_header('Access-Control-Allow-Origin', self.request.headers.get('Origin'))
             self.write(response.content)
         else:
             self.set_status(500)
@@ -581,8 +600,10 @@ class SpecialGatewayApi(tornado.web.RequestHandler):
                 json.loads(response.text, encoding='utf-8')
             except:
                 self._headers = HTTPHeaders(response.headers)  # 注意：需要强制类型转换
-            self.set_header('Access-Control-Allow-Credentials', 'true')
-            self.set_header('Access-Control-Allow-Origin', self.request.headers.get('Origin'))
+
+            if self.request.headers.get('Origin'):
+                self.set_header('Access-Control-Allow-Credentials', 'true')
+                self.set_header('Access-Control-Allow-Origin', self.request.headers.get('Origin'))
             self.write(response.content)
         else:
             self.set_status(500)
